diff src/name/blackcap/clipman/SearchDialog.kt @ 31:0c6c18a733b7

Compiles, new menu still a mess.
author David Barts <n5jrn@me.com>
date Thu, 30 Jan 2020 16:01:51 -0800
parents c4f53bc01732
children 08eaae2aaf76
line wrap: on
line diff
--- a/src/name/blackcap/clipman/SearchDialog.kt	Wed Jan 29 21:56:12 2020 -0800
+++ b/src/name/blackcap/clipman/SearchDialog.kt	Thu Jan 30 16:01:51 2020 -0800
@@ -8,7 +8,6 @@
 import java.awt.event.ActionEvent
 import java.awt.event.ActionListener
 import javax.swing.*
-import javax.swing.border.*
 import javax.swing.event.DocumentEvent
 import javax.swing.event.DocumentListener
 
@@ -58,9 +57,9 @@
         throw RuntimeException("impossible button state!")
     }
 
-    /* standard spacing between elements (18 pixels = 1/4") and half that */
-    private val BW = 9
-    private val BW2 = 2 * BW
+    /* standard spacing between elements (10 pixels ≅ 1/7") and half that */
+    private val BW = 5
+    private val BW2 = 10
 
     /* where to begin searching from. unlike the other properties, this
        one is read/write. null means to start from the beginning on